@@ -1,6 +1,6 @@
 #coding:utf-8
 
-from util import send_mail_util, json_util
+from .util import send_mail_util, json_util
 
 class Tool(object):
     def __init__(self):
