@@ -30,8 +30,8 @@ def json_util(data):
         print("成功转换为dict格式")
         return
     else:
-        # print("请输入json或dict数据")
-        return"请输入json或dict数据"
+        print("请输入json或dict数据")
+        return
 
 
 
